@@ -12,13 +12,13 @@ DEFAULT_NODE_ENVIRONMENT = "application"
 #
 #   INSTALLATION SETTINGS
 #
-PACAKAGE_FOLDER = Path(__file__).parent.parent.parent
+PACKAGE_FOLDER = Path(__file__).parent.parent.parent
 
 NODE_PROXY_SERVER_HOSTNAME = "proxyserver"
 
-DATA_FOLDER = PACAKAGE_FOLDER / APPNAME / "_data"
+DATA_FOLDER = PACKAGE_FOLDER / APPNAME / "_data"
 
-# with open(Path(PACAKAGE_FOLDER) / APPNAME / "node" / "VERSION") as f:
+# with open(Path(PACKAGE_FOLDER) / APPNAME / "node" / "VERSION") as f:
 #     VERSION = f.read()
 
 
@@ -39,3 +39,11 @@ ALPINE_IMAGE = 'harbor2.vantage6.ai/infrastructure/alpine'
 MAX_CHECK_VPN_ATTEMPTS = 60   # max attempts to obtain VPN IP (1 second apart)
 FREE_PORT_RANGE = range(49152, 65535)
 DEFAULT_ALGO_VPN_PORT = '8888'  # default VPN port for algorithm container
+
+#
+#   SSH TUNNEL RELATED CONSTANTS
+#
+SSH_TUNNEL_IMAGE = "harbor2.vantage6.ai/infrastructure/ssh-tunnel"
+
+# start trying to refresh the JWT token 10 minutes before it expires.
+REFRESH_BEFORE_EXPIRES_SECONDS = 600
